@@ -37,8 +37,16 @@ def get_etherscan_uri(ecosystem_name: str, network_name: str):
         return (
             "https://optimistic.etherscan.io"
             if network_name == "mainnet"
-            else "https://kovan-optimistic.etherscan.io"
+            else "https://goerli-optimistic.etherscan.io"
         )
+    elif ecosystem_name == "polygon":
+        return (
+            "https://polygonscan.com"
+            if network_name == "mainnet"
+            else "https://mumbai.polygonscan.com"
+        )
+    elif ecosystem_name == "avalanche":
+        return "https://snowtrace.io"
 
     raise UnsupportedEcosystemError(ecosystem_name)
 
@@ -53,7 +61,7 @@ def get_etherscan_api_uri(ecosystem_name: str, network_name: str):
 
     elif ecosystem_name == "fantom":
         return (
-            f"https://api-{network_name}.ftmscan.com"
+            f"https://api-{network_name}.ftmscan.com/api"
             if network_name != "opera"
             else "https://api.ftmscan.com/api"
         )
@@ -68,8 +76,17 @@ def get_etherscan_api_uri(ecosystem_name: str, network_name: str):
         return (
             "https://api-optimistic.etherscan.io/api"
             if network_name == "mainnet"
-            else "https://api-kovan-optimistic.etherscan.io/api"
+            else "https://api-goerli-optimistic.etherscan.io/api"
         )
+    elif ecosystem_name == "polygon":
+        return (
+            "https://api.polygonscan.com/api"
+            if network_name == "mainnet"
+            else "https://api-testnet.polygonscan.com/api"
+        )
+    elif ecosystem_name == "avalanche":
+        return "https://api.snowtrace.io/api"
+
     raise UnsupportedEcosystemError(ecosystem_name)
 
 
