@@ -8,8 +8,12 @@ import _io  # type: ignore
 import ape
 import pytest
 from ape.api import ExplorerAPI
+from ape.exceptions import NetworkError
+from ape.logging import logger
+from ape.utils import cached_property
 from requests import Response
 
+from ape_etherscan import Etherscan
 from ape_etherscan.client import _APIClient
 from ape_etherscan.types import EtherscanResponse
 
@@ -33,11 +37,31 @@ EXPECTED_ACCOUNT_TXNS_PARAMS = {
     "page": 1,
     "sort": "asc",
 }
-SOURCE_CODE = """
-pragma solidity =0.8.16;
+FOO_SOURCE_CODE = """
+// SPDX-License-Identifier: MIT
+pragma solidity ^0.8.2;
+
+import "@bar/bar.sol";
+
 contract foo {
 }
 """
+BAR_SOURCE_CODE = """
+// SPDX-License-Identifier: MIT
+pragma solidity ^0.8.2;
+
+contract bar {
+}
+"""
+APE_CONFIG_FILE = """
+dependencies:
+  - name: bar
+    local: ./bar
+
+solidity:
+  import_remapping:
+    - "@bar=bar"
+"""
 
 
 @pytest.fixture(autouse=True)
@@ -46,14 +70,27 @@ def connection():
         yield provider
 
 
+def make_source(base_dir: Path, name: str, content: str):
+    source_file = base_dir / f"{name}.sol"
+    source_file.touch()
+    source_file.write_text(content)
+
+
 @pytest.fixture(autouse=True)
 def with_source_file():
-    contracts_dir = ape.config.PROJECT_FOLDER / "contracts"
+    base_dir = ape.config.PROJECT_FOLDER
+    contracts_dir = base_dir / "contracts"
+    dependency_contracts_dir = base_dir / "bar" / "contracts"
     ape.config.contracts_folder = contracts_dir
-    contracts_dir.mkdir(exist_ok=True)
-    source_file = contracts_dir / "foo.sol"
-    source_file.touch()
-    source_file.write_text(SOURCE_CODE)
+    contracts_dir.mkdir(exist_ok=True, parents=True)
+    dependency_contracts_dir.mkdir(exist_ok=True, parents=True)
+
+    make_source(contracts_dir, "foo", FOO_SOURCE_CODE)
+    make_source(dependency_contracts_dir, "bar", BAR_SOURCE_CODE)
+
+    config_file = base_dir / "ape-config.yaml"
+    config_file.unlink(missing_ok=True)
+    config_file.write_text(APE_CONFIG_FILE)
 
 
 @pytest.fixture
@@ -75,14 +112,32 @@ def explorer(get_explorer):
 
 
 @pytest.fixture
-def get_explorer():
+def get_explorer(mocker):
     def fn(
         ecosystem_name: str = "ethereum",
         network_name: str = "development",
     ) -> ExplorerAPI:
-        ecosystem = ape.networks.get_ecosystem(ecosystem_name)
-        explorer = ecosystem.get_network(network_name).explorer
-        assert explorer is not None
+        try:
+            ecosystem = ape.networks.get_ecosystem(ecosystem_name)
+        except NetworkError:
+            # Use mock
+            logger.warning(
+                f"Ecosystem 'ape-{ecosystem_name}' not installed; resorting to a mock ecosystem."
+            )
+            ecosystem = mocker.MagicMock()
+            ecosystem.name = ecosystem_name
+            network = mocker.MagicMock()
+            network.name = network_name
+            network.ecosystem = ecosystem
+            etherscan = ape.networks.get_ecosystem("ethereum").get_network("mainnet")
+            explorer = Etherscan.construct(name=etherscan.name, network=network)
+            network.explorer = explorer
+            explorer.network = network
+        else:
+            network = ecosystem.get_network(network_name)
+            explorer = network.explorer
+            assert explorer is not None
+
         return explorer
 
     return fn
@@ -109,13 +164,39 @@ class MockEtherscanBackend:
         self._expected_base_uri = "https://api.etherscan.io/api"  # Default
         self._handlers = {"get": {}, "post": {}}
 
-    def set_ecosystem(self, ecosystem):
-        expected_uri_map = {
-            "ethereum": "https://api.etherscan.io/api",
-            "fantom": "https://api.ftmscan.com/api",
-            "optimism": "https://api-optimistic.etherscan.io/api",
+    @cached_property
+    def expected_uri_map(
+        self,
+    ) -> Dict[str, Dict[str, str]]:
+        def get_url_f(testnet: bool = False, tld: str = "io"):
+            f_str = f"https://api-{{}}.{{}}.{tld}/api" if testnet else f"https://api.{{}}.{tld}/api"
+            return f_str.format
+
+        url = get_url_f()
+        testnet_url = get_url_f(testnet=True)
+        com_url = get_url_f(tld="com")
+        com_testnet_url = get_url_f(testnet=True, tld="com")
+
+        return {
+            "ethereum": {"mainnet": url("etherscan"), "goerli": testnet_url("goerli", "etherscan")},
+            "arbitrum": {"mainnet": url("arbiscan"), "goerli": testnet_url("goerli", "arbiscan")},
+            "fantom": {
+                "opera": com_url("ftmscan"),
+                "testnet": com_testnet_url("testnet", "ftmscan"),
+            },
+            "optimism": {
+                "mainnet": testnet_url("optimistic", "etherscan"),
+                "goerli": testnet_url("goerli-optimistic", "etherscan"),
+            },
+            "polygon": {
+                "mainnet": com_url("polygonscan"),
+                "mumbai": com_testnet_url("testnet", "polygonscan"),
+            },
+            "avalanche": {"mainnet": url("snowtrace")},
         }
-        self._expected_base_uri = expected_uri_map[ecosystem]
+
+    def set_network(self, ecosystem: str, network: str):
+        self._expected_base_uri = self.expected_uri_map[ecosystem][network.replace("-fork", "")]
 
     def add_handler(self, method, module, expected_params, return_value=None, side_effect=None):
         if isinstance(return_value, (str, dict)):
@@ -179,7 +260,7 @@ class MockEtherscanBackend:
         with open(test_data_path) as response_data_file:
             response = self.get_mock_response(response_data_file, file_name=file_name)
             self.add_handler("GET", "account", EXPECTED_ACCOUNT_TXNS_PARAMS, return_value=response)
-            self.set_ecosystem("ethereum")
+            self.set_network("ethereum", "mainnet")
             return response
 
     def get_mock_response(self, response_data: Union[IO, Dict, str], **kwargs):
